==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/NullCheckStmt.h <==
// public class org.dellroad.jc.cgen.NullCheckStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3b6a3139db3c275f org_dellroad_jc_cgen_NullCheckStmt
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 9bd832fad7d8404f soot_jimple_internal_JInvokeStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JInvokeStmt

#include "soot/jimple/internal/JInvokeStmt.h"

#ifndef _JC_org_dellroad_jc_cgen_NullCheckStmt_H_
#define _JC_org_dellroad_jc_cgen_NullCheckStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_PatchingChain$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_refs	_jc_org_dellroad_jc_cgen_NullCheckStmt$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_nonrefs	_jc_org_dellroad_jc_cgen_NullCheckStmt$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$refs	_jc_org_dellroad_jc_cgen_NullCheckStmt$refs;
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$nonrefs	_jc_org_dellroad_jc_cgen_NullCheckStmt$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object	_jc_org_dellroad_jc_cgen_NullCheckStmt$object;

typedef const struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vmethods	_jc_org_dellroad_jc_cgen_NullCheckStmt$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vtable	_jc_org_dellroad_jc_cgen_NullCheckStmt$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vtype	_jc_org_dellroad_jc_cgen_NullCheckStmt$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_NullCheckStmt$method$_init$b01f06481db4410b(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_org_dellroad_jc_cgen_NullCheckStmt$method$getNullCheckValue$f81be99366292e10(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_NullCheckStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *);
extern void _jc_org_dellroad_jc_cgen_NullCheckStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_NullCheckStmt$method_info$getNullCheckValue$f81be99366292e10;
extern _jc_method _jc_org_dellroad_jc_cgen_NullCheckStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_org_dellroad_jc_cgen_NullCheckStmt$method_info$toString$49ce0d4a4e59c2a6;

// Static methods
extern struct _jc_soot_SootMethod$object *_jc_org_dellroad_jc_cgen_NullCheckStmt$method$getNullCheckMethod$c0aef3684dc53a46(_jc_env *);
extern void _jc_org_dellroad_jc_cgen_NullCheckStmt$method$insertNullCheck$cf9688b692f73f66(_jc_env *, struct _jc_soot_PatchingChain$object *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_org_dellroad_jc_cgen_NullCheckStmt$method$isNullCheck$3c1478167381009e(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vmethods {
	struct _jc_object	*(*getNullCheckValue$f81be99366292e10)(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *, struct _jc_object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JInvokeStmt$vmethods	soot_jimple_internal_JInvokeStmt;
	_jc_org_dellroad_jc_cgen_NullCheckStmt$vmethods	org_dellroad_jc_cgen_NullCheckStmt;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_NullCheckStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$refs {
    _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_refs	org_dellroad_jc_cgen_NullCheckStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_refs	soot_jimple_internal_JInvokeStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_nonrefs	soot_jimple_internal_JInvokeStmt;
    _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_nonrefs	org_dellroad_jc_cgen_NullCheckStmt;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object {
	_jc_org_dellroad_jc_cgen_NullCheckStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_NullCheckStmt$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_NullCheckStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_NullCheckStmt$vtype _jc_org_dellroad_jc_cgen_NullCheckStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_NullCheckStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_NullCheckStmt$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_NullCheckStmt_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/NullCheckStmt.h <==
// public class org.dellroad.jc.cgen.NullCheckStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3b6a3139db3c275f org_dellroad_jc_cgen_NullCheckStmt
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 9bd832fad7d8404f soot_jimple_internal_JInvokeStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JInvokeStmt

#include "soot/jimple/internal/JInvokeStmt.h"

#ifndef _JC_org_dellroad_jc_cgen_NullCheckStmt_H_
#define _JC_org_dellroad_jc_cgen_NullCheckStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_PatchingChain$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_refs	_jc_org_dellroad_jc_cgen_NullCheckStmt$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_nonrefs	_jc_org_dellroad_jc_cgen_NullCheckStmt$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$refs	_jc_org_dellroad_jc_cgen_NullCheckStmt$refs;
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$nonrefs	_jc_org_dellroad_jc_cgen_NullCheckStmt$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object	_jc_org_dellroad_jc_cgen_NullCheckStmt$object;

typedef const struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vmethods	_jc_org_dellroad_jc_cgen_NullCheckStmt$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vtable	_jc_org_dellroad_jc_cgen_NullCheckStmt$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vtype	_jc_org_dellroad_jc_cgen_NullCheckStmt$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_NullCheckStmt$method$_init$b01f06481db4410b(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_org_dellroad_jc_cgen_NullCheckStmt$method$getNullCheckValue$f81be99366292e10(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_NullCheckStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_NullCheckStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_NullCheckStmt$method_info$getNullCheckValue$f81be99366292e10;
extern _jc_method _jc_org_dellroad_jc_cgen_NullCheckStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_org_dellroad_jc_cgen_NullCheckStmt$method_info$toString$49ce0d4a4e59c2a6;

// Static methods
extern struct _jc_soot_SootMethod$object *_jc_org_dellroad_jc_cgen_NullCheckStmt$method$getNullCheckMethod$c0aef3684dc53a46(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_NullCheckStmt$method$insertNullCheck$cf9688b692f73f66(_jc_env *, struct _jc_soot_PatchingChain$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_org_dellroad_jc_cgen_NullCheckStmt$method$isNullCheck$3c1478167381009e(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vmethods {
	struct _jc_object	*(*getNullCheckValue$f81be99366292e10)(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JInvokeStmt$vmethods	soot_jimple_internal_JInvokeStmt;
	_jc_org_dellroad_jc_cgen_NullCheckStmt$vmethods	org_dellroad_jc_cgen_NullCheckStmt;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_NullCheckStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$refs {
    _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_refs	org_dellroad_jc_cgen_NullCheckStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_refs	soot_jimple_internal_JInvokeStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_nonrefs	soot_jimple_internal_JInvokeStmt;
    _jc_org_dellroad_jc_cgen_NullCheckStmt$sub_nonrefs	org_dellroad_jc_cgen_NullCheckStmt;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_NullCheckStmt$object {
	_jc_org_dellroad_jc_cgen_NullCheckStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_NullCheckStmt$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_NullCheckStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_NullCheckStmt$vtype _jc_org_dellroad_jc_cgen_NullCheckStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_NullCheckStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_NullCheckStmt$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_NullCheckStmt_H_ */
